@@ -225,11 +225,6 @@ QVariant MessageContentModel::data(const QModelIndex &index, int role) const
         if (m_event == nullptr) {
             return QString();
         }
-        if (m_event->isRedacted()) {
-            auto reason = m_event->redactedBecause()->reason();
-            return (reason.isEmpty()) ? i18n("<i>[This message was deleted]</i>")
-                                      : i18n("<i>[This message was deleted: %1]</i>", m_event->redactedBecause()->reason());
-        }
         if (!component.content.isEmpty()) {
             return component.content;
         }
@@ -514,7 +509,7 @@ MessageComponent MessageContentModel::linkPreviewComponent(const QUrl &link)
     if (linkPreviewer->loaded()) {
         return MessageComponent{MessageComponentType::LinkPreview, QString(), {{"link"_ls, link}}};
     } else {
-        connect(linkPreviewer, &LinkPreviewer::loadedChanged, [this, link]() {
+        connect(linkPreviewer, &LinkPreviewer::loadedChanged, this, [this, link]() {
             const auto linkPreviewer = dynamic_cast<NeoChatConnection *>(m_room->connection())->previewerForLink(link);
             if (linkPreviewer != nullptr && linkPreviewer->loaded()) {
                 for (auto &component : m_components) {
@@ -555,6 +550,11 @@ QList<MessageComponent> MessageContentModel::addLinkPreviews(QList<MessageCompon
 
 void MessageContentModel::closeLinkPreview(int row)
 {
+    if (row < 0 || row > m_components.size()) {
+        qWarning() << "closeLinkPreview() called with row" << row << "which does not exist. m_components.size() =" << m_components.size();
+        return;
+    }
+
     if (m_components[row].type == MessageComponentType::LinkPreview || m_components[row].type == MessageComponentType::LinkPreviewLoad) {
         beginResetModel();
         m_removedLinkPreviews += m_components[row].attributes["link"_ls].toUrl();
