@@ -134,7 +134,11 @@ NeoChatRoom::NeoChatRoom(Connection *connection, QString roomId, JoinState joinS
             auto showNotification = [this, roomMemberEvent] {
                 QImage avatar_image;
                 if (roomMemberEvent && !member(roomMemberEvent->senderId()).avatarUrl().isEmpty()) {
+#if Quotient_VERSION_MINOR > 8
+                    avatar_image = member(roomMemberEvent->senderId()).avatar(128, 128, {});
+#else
                     avatar_image = memberAvatar(roomMemberEvent->senderId()).get(this->connection(), 128, [] {});
+#endif
                 } else {
                     qWarning() << "using this room's avatar";
                     avatar_image = avatar(128);
@@ -1223,7 +1227,11 @@ void NeoChatRoom::setPushNotificationState(PushNotificationState::State state)
         for (const auto &i : roomRuleArray) {
             QJsonObject roomRule = i.toObject();
             if (roomRule["rule_id"_ls] == id()) {
-                connection()->callApi<DeletePushRuleJob>("global"_ls, "room"_ls, id());
+#if Quotient_VERSION_MINOR > 8
+                connection()->callApi<DeletePushRuleJob>("room"_ls, id());
+#else
+                connection()->callApi<DeletePushRuleJob>(QLatin1String("global"), "room"_ls, id());
+#endif
             }
         }
     }
@@ -1234,7 +1242,11 @@ void NeoChatRoom::setPushNotificationState(PushNotificationState::State state)
         for (const auto &i : overrideRuleArray) {
             QJsonObject overrideRule = i.toObject();
             if (overrideRule["rule_id"_ls] == id()) {
+#if Quotient_VERSION_MINOR > 8
+                connection()->callApi<DeletePushRuleJob>("override"_ls, id());
+#else
                 connection()->callApi<DeletePushRuleJob>("global"_ls, "override"_ls, id());
+#endif
             }
         }
     }
@@ -1270,9 +1282,17 @@ void NeoChatRoom::setPushNotificationState(PushNotificationState::State state)
         const QList<PushCondition> conditions = {pushCondition};
 
         // Add new override rule and make sure it's enabled
+#if Quotient_VERSION_MINOR > 8
+        auto job = connection()->callApi<SetPushRuleJob>("override"_ls, id(), actions, QString(), QString(), conditions, QString());
+#else
         auto job = connection()->callApi<SetPushRuleJob>("global"_ls, "override"_ls, id(), actions, QString(), QString(), conditions, QString());
+#endif
         connect(job, &BaseJob::success, this, [this]() {
+#if Quotient_VERSION_MINOR > 8
+            auto enableJob = connection()->callApi<SetPushRuleEnabledJob>("override"_ls, id(), true);
+#else
             auto enableJob = connection()->callApi<SetPushRuleEnabledJob>("global"_ls, "override"_ls, id(), true);
+#endif
             connect(enableJob, &BaseJob::success, this, [this]() {
                 m_pushNotificationStateUpdating = false;
             });
@@ -1296,9 +1316,17 @@ void NeoChatRoom::setPushNotificationState(PushNotificationState::State state)
         // No conditions for a room rule
         const QList<PushCondition> conditions;
 
+#if Quotient_VERSION_MINOR > 8
+        auto setJob = connection()->callApi<SetPushRuleJob>("room"_ls, id(), actions, QString(), QString(), conditions, QString());
+#else
         auto setJob = connection()->callApi<SetPushRuleJob>("global"_ls, "room"_ls, id(), actions, QString(), QString(), conditions, QString());
+#endif
         connect(setJob, &BaseJob::success, this, [this]() {
+#if Quotient_VERSION_MINOR > 8
+            auto enableJob = connection()->callApi<SetPushRuleEnabledJob>("room"_ls, id(), true);
+#else
             auto enableJob = connection()->callApi<SetPushRuleEnabledJob>("global"_ls, "room"_ls, id(), true);
+#endif
             connect(enableJob, &BaseJob::success, this, [this]() {
                 m_pushNotificationStateUpdating = false;
             });
@@ -1327,9 +1355,17 @@ void NeoChatRoom::setPushNotificationState(PushNotificationState::State state)
         const QList<PushCondition> conditions;
 
         // Add new room rule and make sure enabled
+#if Quotient_VERSION_MINOR > 8
+        auto setJob = connection()->callApi<SetPushRuleJob>("room"_ls, id(), actions, QString(), QString(), conditions, QString());
+#else
         auto setJob = connection()->callApi<SetPushRuleJob>("global"_ls, "room"_ls, id(), actions, QString(), QString(), conditions, QString());
+#endif
         connect(setJob, &BaseJob::success, this, [this]() {
+#if Quotient_VERSION_MINOR > 8
+            auto enableJob = connection()->callApi<SetPushRuleEnabledJob>("room"_ls, id(), true);
+#else
             auto enableJob = connection()->callApi<SetPushRuleEnabledJob>("global"_ls, "room"_ls, id(), true);
+#endif
             connect(enableJob, &BaseJob::success, this, [this]() {
                 m_pushNotificationStateUpdating = false;
             });
@@ -1705,9 +1741,13 @@ int NeoChatRoom::maxRoomVersion() const
     return maxVersion;
 }
 
-Quotient::RoomMember NeoChatRoom::directChatRemoteMember() const
+NeochatRoomMember *NeoChatRoom::directChatRemoteMember()
 {
-    return directChatMembers()[0];
+    if (directChatMembers().size() == 0) {
+        qWarning() << "No other member available in this room";
+        return {};
+    }
+    return new NeochatRoomMember(this, directChatMembers()[0].id());
 }
 
 void NeoChatRoom::sendLocation(float lat, float lon, const QString &description)
