@@ -6,7 +6,6 @@
 #include <QDBusMetaType>
 
 #include "controller.h"
-#include "neochatroom.h"
 #include "roomlistmodel.h"
 #include "roommanager.h"
 #include "sortfilterroomlistmodel.h"
@@ -43,17 +42,6 @@ Runner::Runner()
     qDBusRegisterMetaType<RemoteImage>();
 }
 
-void Runner::setRoomListModel(RoomListModel *roomListModel)
-{
-    m_model->setSourceModel(roomListModel);
-    Q_EMIT roomListModelChanged();
-}
-
-RoomListModel *Runner::roomListModel() const
-{
-    return dynamic_cast<RoomListModel *>(m_model->sourceModel());
-}
-
 RemoteActions Runner::Actions()
 {
     return {};
